==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/Patented/Patented.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkPatentedInstantiator(void);
extern SWIGEXPORT(void) Init_vtkDecimate(void);
extern SWIGEXPORT(void) Init_vtkDividingCubes(void);
extern SWIGEXPORT(void) Init_vtkGridSynchronizedTemplates3D(void);
extern SWIGEXPORT(void) Init_vtkImageMarchingCubes(void);
extern SWIGEXPORT(void) Init_vtkKitwareContourFilter(void);
extern SWIGEXPORT(void) Init_vtkMarchingContourFilter(void);
extern SWIGEXPORT(void) Init_vtkMarchingCubes(void);
extern SWIGEXPORT(void) Init_vtkMarchingSquares(void);
extern SWIGEXPORT(void) Init_vtkSliceCubes(void);
extern SWIGEXPORT(void) Init_vtkSweptSurface(void);
extern SWIGEXPORT(void) Init_vtkSynchronizedTemplates2D(void);
extern SWIGEXPORT(void) Init_vtkSynchronizedTemplates3D(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Patented(void){

  Init_vtkPatentedInstantiator();
  Init_vtkDecimate();
  Init_vtkDividingCubes();
  Init_vtkGridSynchronizedTemplates3D();
  Init_vtkImageMarchingCubes();
  Init_vtkKitwareContourFilter();
  Init_vtkMarchingContourFilter();
  Init_vtkMarchingCubes();
  Init_vtkMarchingSquares();
  Init_vtkSliceCubes();
  Init_vtkSweptSurface();
  Init_vtkSynchronizedTemplates2D();
  Init_vtkSynchronizedTemplates3D();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/Patented/Patented.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkPatentedInstantiator(void);
extern SWIGEXPORT(void) Init_vtkDecimate(void);
extern SWIGEXPORT(void) Init_vtkDividingCubes(void);
extern SWIGEXPORT(void) Init_vtkGridSynchronizedTemplates3D(void);
extern SWIGEXPORT(void) Init_vtkImageMarchingCubes(void);
extern SWIGEXPORT(void) Init_vtkKitwareContourFilter(void);
extern SWIGEXPORT(void) Init_vtkKitwareCutter(void);
extern SWIGEXPORT(void) Init_vtkMarchingContourFilter(void);
extern SWIGEXPORT(void) Init_vtkMarchingCubes(void);
extern SWIGEXPORT(void) Init_vtkMarchingSquares(void);
extern SWIGEXPORT(void) Init_vtkRectilinearSynchronizedTemplates(void);
extern SWIGEXPORT(void) Init_vtkSliceCubes(void);
extern SWIGEXPORT(void) Init_vtkSweptSurface(void);
extern SWIGEXPORT(void) Init_vtkSynchronizedTemplates2D(void);
extern SWIGEXPORT(void) Init_vtkSynchronizedTemplates3D(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Patented(void){

  Init_vtkPatentedInstantiator();
  Init_vtkDecimate();
  Init_vtkDividingCubes();
  Init_vtkGridSynchronizedTemplates3D();
  Init_vtkImageMarchingCubes();
  Init_vtkKitwareContourFilter();
  Init_vtkKitwareCutter();
  Init_vtkMarchingContourFilter();
  Init_vtkMarchingCubes();
  Init_vtkMarchingSquares();
  Init_vtkRectilinearSynchronizedTemplates();
  Init_vtkSliceCubes();
  Init_vtkSweptSurface();
  Init_vtkSynchronizedTemplates2D();
  Init_vtkSynchronizedTemplates3D();
}
